[gtksourceview] SearchContext: rename backward2() -> backward()



commit 2a065c5d45cbb08a8c780246aa487b6e919f4b0f
Author: Sébastien Wilmet <swilmet gnome org>
Date:   Tue Nov 15 18:19:59 2016 +0100

    SearchContext: rename backward2() -> backward()
    
    https://bugzilla.gnome.org/show_bug.cgi?id=773249

 docs/reference/gtksourceview-4.0-sections.txt |    2 +-
 gtksourceview/gtksourcesearchcontext.c        |   18 +++++++-------
 gtksourceview/gtksourcesearchcontext.h        |    2 +-
 testsuite/test-search-context.c               |   30 ++++++++++++------------
 4 files changed, 26 insertions(+), 26 deletions(-)
---
diff --git a/docs/reference/gtksourceview-4.0-sections.txt b/docs/reference/gtksourceview-4.0-sections.txt
index 7e656c6..679e8e1 100644
--- a/docs/reference/gtksourceview-4.0-sections.txt
+++ b/docs/reference/gtksourceview-4.0-sections.txt
@@ -685,7 +685,7 @@ gtk_source_search_context_get_occurrence_position
 gtk_source_search_context_forward
 gtk_source_search_context_forward_async
 gtk_source_search_context_forward_finish
-gtk_source_search_context_backward2
+gtk_source_search_context_backward
 gtk_source_search_context_backward_async
 gtk_source_search_context_backward_finish2
 gtk_source_search_context_replace2
diff --git a/gtksourceview/gtksourcesearchcontext.h b/gtksourceview/gtksourcesearchcontext.h
index cef2abb..b06a7ae 100644
--- a/gtksourceview/gtksourcesearchcontext.h
+++ b/gtksourceview/gtksourcesearchcontext.h
@@ -116,7 +116,7 @@ gboolean             gtk_source_search_context_forward_finish               
(GtkSourceSearchContext  *s
                                                                                 GError                 
**error);
 
 GTK_SOURCE_AVAILABLE_IN_3_22
-gboolean                gtk_source_search_context_backward2                    (GtkSourceSearchContext 
*search,
+gboolean                gtk_source_search_context_backward                     (GtkSourceSearchContext 
*search,
                                                                                 const GtkTextIter      *iter,
                                                                                 GtkTextIter            
*match_start,
                                                                                 GtkTextIter            
*match_end,
diff --git a/testsuite/test-search-context.c b/testsuite/test-search-context.c
index e7ef896..42303b0 100644
--- a/testsuite/test-search-context.c
+++ b/testsuite/test-search-context.c
@@ -455,11 +455,11 @@ check_search_results (GtkSourceBuffer        *source_buffer,
                }
                else
                {
-                       found = gtk_source_search_context_backward2 (context,
-                                                                    &iter,
-                                                                    &match_start,
-                                                                    &match_end,
-                                                                    &has_wrapped_around);
+                       found = gtk_source_search_context_backward (context,
+                                                                   &iter,
+                                                                   &match_start,
+                                                                   &match_end,
+                                                                   &has_wrapped_around);
                }
 
                g_assert_cmpint (found, ==, results[i].found);
@@ -1162,11 +1162,11 @@ test_regex_look_behind (void)
 
        /* Backward search */
        gtk_text_buffer_get_end_iter (text_buffer, &iter);
-       found = gtk_source_search_context_backward2 (context,
-                                                    &iter,
-                                                    &match_start,
-                                                    &match_end,
-                                                    &has_wrapped_around);
+       found = gtk_source_search_context_backward (context,
+                                                   &iter,
+                                                   &match_start,
+                                                   &match_end,
+                                                   &has_wrapped_around);
        g_assert (found);
        g_assert (!has_wrapped_around);
 
@@ -1248,11 +1248,11 @@ test_regex_look_ahead (void)
 
        /* Backward search */
        gtk_text_buffer_get_end_iter (text_buffer, &iter);
-       found = gtk_source_search_context_backward2 (context,
-                                                    &iter,
-                                                    &match_start,
-                                                    &match_end,
-                                                    &has_wrapped_around);
+       found = gtk_source_search_context_backward (context,
+                                                   &iter,
+                                                   &match_start,
+                                                   &match_end,
+                                                   &has_wrapped_around);
        g_assert (found);
        g_assert (!has_wrapped_around);
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtksourceview/gtksourcesearchcontext.c b/gtksourceview/gtksourcesearchcontext.c
index ad12058..afe4132 100644
--- a/gtksourceview/gtksourcesearchcontext.c
+++ b/gtksourceview/gtksourcesearchcontext.c
@@ -3373,7 +3373,7 @@ gtk_source_search_context_forward_finish (GtkSourceSearchContext  *search,
 }
 
 /**
- * gtk_source_search_context_backward2:
+ * gtk_source_search_context_backward:
  * @search: a #GtkSourceSearchContext.
  * @iter: start of search.
  * @match_start: (out) (optional): return location for start of match, or %NULL.
@@ -3396,11 +3396,11 @@ gtk_source_search_context_forward_finish (GtkSourceSearchContext  *search,
  * Since: 3.22
  */
 gboolean
-gtk_source_search_context_backward2 (GtkSourceSearchContext *search,
-                                    const GtkTextIter      *iter,
-                                    GtkTextIter            *match_start,
-                                    GtkTextIter            *match_end,
-                                    gboolean               *has_wrapped_around)
+gtk_source_search_context_backward (GtkSourceSearchContext *search,
+                                   const GtkTextIter      *iter,
+                                   GtkTextIter            *match_start,
+                                   GtkTextIter            *match_end,
+                                   gboolean               *has_wrapped_around)
 {
        GtkTextIter m_start;
        GtkTextIter m_end;
@@ -3456,9 +3456,9 @@ gtk_source_search_context_backward2 (GtkSourceSearchContext *search,
  * @callback: a #GAsyncReadyCallback to call when the operation is finished.
  * @user_data: the data to pass to the @callback function.
  *
  * The asynchronous version of gtk_source_search_context_backward2().
  *
  * See the documentation of gtk_source_search_context_backward2() for more
  * details.
  *
  * See the #GAsyncResult documentation to know how to use this function.
@@ -3503,7 +3503,7 @@ gtk_source_search_context_backward_async (GtkSourceSearchContext *search,
  * Finishes a backward search started with
  * gtk_source_search_context_backward_async().
  *
  * See the documentation of gtk_source_search_context_backward2() for more
  * details.
  *
  * Returns: whether a match was found.
@@ -3456,9 +3456,9 @@ gtk_source_search_context_backward2 (GtkSourceSearchContext *search,
  * @user_data: the data to pass to the @callback function.
  *
- * The asynchronous version of gtk_source_search_context_backward2().
+ * The asynchronous version of gtk_source_search_context_backward().
  *
@@ -3456,9 +3456,9 @@ gtk_source_search_context_backward2 (GtkSourceSearchContext *search,
  *
- * See the documentation of gtk_source_search_context_backward2() for more
+ * See the documentation of gtk_source_search_context_backward() for more
  * details.
  *
@@ -3503,7 +3503,7 @@ gtk_source_search_context_backward_async (GtkSourceSearchContext *search,
  * gtk_source_search_context_backward_async().
  *
- * See the documentation of gtk_source_search_context_backward2() for more
+ * See the documentation of gtk_source_search_context_backward() for more
  * details.
  *